﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Telerik.WinControls;
using Telerik.WinControls.UI;

namespace _1432409
{
    public partial class RadForm1 : Telerik.WinControls.UI.RadForm
    {
        public RadForm1()
        {
            InitializeComponent();

            foreach (KeyValuePair<string, IList<Color>> pair in ThemesColors)
            {
                string themeName = pair.Key;
                this.AddThemeItem(themeName, pair.Value);
            }
        }

        private void AddThemeItem(string text, IList<Color> colors)
        {

            RadListDataItem item = new RadListDataItem(text);
            Image image = this.CreateBitmapFromColors(colors);

            item.Image = image;
            item.TextImageRelation = TextImageRelation.TextBeforeImage;
            item.ImageAlignment = ContentAlignment.MiddleRight;
            this.themesListControl.Items.Add(item);
        }
        private Image CreateBitmapFromColors(IList<Color> colors)
        {
            int cellWidth = 14;
            Bitmap bitmap = new Bitmap(colors.Count * cellWidth + 2, cellWidth + 2);
            using (Graphics g = Graphics.FromImage(bitmap))
            {
                Rectangle colorRect = new Rectangle(1, 1, cellWidth, cellWidth);
                foreach (Color color in colors)
                {
                    using (SolidBrush brush = new SolidBrush(color))
                    {
                        g.FillRectangle(brush, colorRect);
                    }

                    colorRect.X += cellWidth;
                }

                Rectangle fullRect = new Rectangle(0, 0, bitmap.Width, bitmap.Height);
                fullRect.Width -= 1;
                fullRect.Height -= 1;
                g.DrawRectangle(Pens.DarkGray, fullRect);
            }

            return bitmap;
        }
        public static IDictionary<string, IList<Color>> themesColors;

        public static IDictionary<string, IList<Color>> ThemesColors
        {
            get
            {
                if (themesColors == null)
                {
                    themesColors = new Dictionary<string, IList<Color>>();
                    themesColors.Add(
                        "Crystal",
                        CreateColorListByHEX("#FF1C83FF", "#FFCDCDCD", "#FF0060CF"));
                    themesColors.Add(
                        "CrystalDark",
                        CreateColorListByHEX("#FF1C83FF", "#FF3A3A3A", "#FF0060CF"));
                    themesColors.Add(
                        "Fluent",
                        CreateColorListByHEX("#009BC0", "#E8EAEB", "#15DAFF"));
                    themesColors.Add(
                        "FluentDark",
                        CreateColorListByHEX("#009BC0", "#333333", "#15DAFF"));
                    themesColors.Add(
                        "Office2013Dark",
                        CreateColorListByHEX("#676767", "#B1D6F0", "#F3F3F3"));
                    themesColors.Add(
                        "Office2013Light",
                        CreateColorListByHEX("#F0F0F0", "#B1D6F0", "#FFFFFF"));
                    themesColors.Add(
                        "Windows8",
                        CreateColorListByHEX("#FFFFFF", "#44ADDF", "#D6D6D6"));
                    themesColors.Add(
                        "VisualStudio2012Dark",
                        CreateColorListByHEX("#252526", "#3399FF", "#F1F1F1"));
                    themesColors.Add(
                        "VisualStudio2012Light",
                        CreateColorListByHEX("#FFFFFF", "#3399FF", "#D8D8DD"));
                    themesColors.Add(
                        "TelerikMetro",
                        CreateColorListByHEX("#A7AE84", "#90B808", "#FFFFFF"));
                    themesColors.Add(
                        "TelerikMetroBlue",
                        CreateColorListByHEX("#83BADE", "#1BA1E2", "#FFFFFF"));
                    themesColors.Add(
                        "TelerikMetroTouch",
                        CreateColorListByHEX("#A7AE84", "#90B808", "#FFFFFF"));
                    themesColors.Add(
                        "Office2010Black",
                        CreateColorListByHEX("#929292", "#F5BF41", "#5C5C5C"));
                    themesColors.Add(
                        "Office2010Silver",
                        CreateColorListByHEX("#4B4E61", "#F5BF41", "#E1E4E8"));
                    themesColors.Add(
                        "Office2010Blue",
                        CreateColorListByHEX("#4677B3", "#F5BF41", "#CADDF0"));
                    themesColors.Add(
                        "ControlDefault",
                        CreateColorListByHEX("#0D3683", "#FFD67E", "#D5E5FB"));
                    themesColors.Add(
                        "Aqua",
                        CreateColorListByHEX("#8B8B8B", "#EDEDED", "#2D89DC"));
                    themesColors.Add(
                        "Breeze",
                        CreateColorListByHEX("#4B4C4D", "#3297FE", "#D3E7FC"));
                    themesColors.Add(
                        "Desert",
                        CreateColorListByHEX("#DDDDD0", "#EEA43F", "#49B7C5"));
                    themesColors.Add(
                        "HighContrastBlack",
                        CreateColorListByHEX("#000000", "#008000", "#800080"));
                    themesColors.Add(
                        "Office2007Black",
                        CreateColorListByHEX("#686868", "#EEAB6B", "#CACACA"));
                    themesColors.Add(
                        "Office2007Silver",
                        CreateColorListByHEX("#DCE0E7", "#EEAB6B", "#CACACA"));
                    themesColors.Add(
                        "Windows7",
                        CreateColorListByHEX("#FFFFFF", "#86AEE1", "#D5D5D5"));
                    themesColors.Add(
                        "Material",
                        CreateColorListByHEX("#3F51B5", "#E0E0E0", "#FF9100"));
                    themesColors.Add(
                        "MaterialPink",
                        CreateColorListByHEX("#E91E63", "#E0E0E0", "#448AFF"));
                    themesColors.Add(
                        "MaterialTeal",
                        CreateColorListByHEX("#009688", "#E0E0E0", "#FF5252"));
                    themesColors.Add(
                        "MaterialBlueGrey",
                        CreateColorListByHEX("#607D8B", "#E0E0E0", "#69F0AE"));
                }

                return themesColors;
            }
        }
        private static IList<Color> CreateColorListByHEX(params string[] colorStrings)
        {
            List<Color> colors = new List<Color>();
            foreach (string colorString in colorStrings)
            {
                colors.Add(ColorTranslator.FromHtml(colorString));
            }

            return colors;
        }
    }
}
